==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/KbarticlecommentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Kbarticlecomment;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.KbarticlecommentRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class KbarticlecommentCollectionRequest extends CollectionPageEntityRequest<Kbarticlecomment, KbarticlecommentRequest>{

    protected ContextPath contextPath;

    public KbarticlecommentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Kbarticlecomment.class, cp -> new KbarticlecommentRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public BulkdeletefailureCollectionRequest kbArticleComment_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("KbArticleComment_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest kbArticleComment_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("KbArticleComment_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest kbArticleComment_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("KbArticleComment_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest kbArticleComment_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("KbArticleComment_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest kbArticleComment_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("KbArticleComment_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest kbArticleComment_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("KbArticleComment_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/KbarticlecommentCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Kbarticlecomment;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.KbarticlecommentRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;

public class KbarticlecommentCollectionRequest extends CollectionPageEntityRequest<Kbarticlecomment, KbarticlecommentRequest>{

    protected ContextPath contextPath;

    public KbarticlecommentCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Kbarticlecomment.class, cp -> new KbarticlecommentRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public BulkdeletefailureCollectionRequest kbArticleComment_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("KbArticleComment_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest kbArticleComment_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("KbArticleComment_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest kbArticleComment_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("KbArticleComment_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest kbArticleComment_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("KbArticleComment_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest kbArticleComment_ProcessSessions() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("KbArticleComment_ProcessSessions"), Optional.empty());
    }

    public ProcesssessionRequest kbArticleComment_ProcessSessions(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("KbArticleComment_ProcessSessions").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

}
